@@ -2,7 +2,7 @@ print.hiddenf <-
 function(x,...)
 {
 cat("The F-Test for Hidden Additivity \n")
-hfanova <- anova(x)
+hfanova <- anova(x,warncat=FALSE)
 Fratio <- prettyNum(hfanova$F[4],digits=4)
 pvalue <- prettyNum(x$adjpvalue,digits=4)
 cat(paste("F=",Fratio," p-value =",pvalue," df=",hfanova$Df[4],",",hfanova$Df[5],"\n",sep=""))
